==> open_watcom_1.4.0-src.zip: bld/clib/startup/c/cmain086.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  Implementation of _CMain() for 16-bit x86 platforms.
*
****************************************************************************/


#include <stdio.h>
#include <stdlib.h>
#include <malloc.h>

#pragma aux     _CMain  "_*";

/*
        ___Argc, ___Argv will be filled in by an initializer routine
        if main is defined with parameters.
*/
_WCRTLINK extern        int     ___Argc;        /* argument count */
_WCRTLINK extern        char ** ___Argv;        /* argument vector */


#if defined(__SW_BD)
extern unsigned __dll_initialize( void );
int _CMain( void )
{
    _amblksiz = 8 * 1024;   /* set minimum memory block allocation */
    return( __dll_initialize() );
}
#else
extern int     main( int, char ** );
void _CMain( void )
{
    _amblksiz = 8 * 1024;   /* set minimum memory block allocation */
    exit( main( ___Argc, ___Argv ) );
}
#endif

==> open_watcom_1.5.0-src.zip: bld/clib/startup/c/cmain086.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  Implementation of _CMain() for 16-bit x86 platforms.
*
****************************************************************************/


#include <stdio.h>
#include <stdlib.h>
#include <malloc.h>
#include "widechar.h"
#include "initarg.h"

#pragma aux     _CMain  "_*";

/*
        ___Argc, ___Argv will be filled in by an initializer routine
        if main is defined with parameters.
*/

#if defined(__SW_BD)
extern unsigned __dll_initialize( void );
int _CMain( void )
{
    _amblksiz = 8 * 1024;   /* set minimum memory block allocation */
    return( __dll_initialize() );
}
#else
extern int     main( int, char ** );
void _CMain( void )
{
    _amblksiz = 8 * 1024;   /* set minimum memory block allocation */
    exit( main( ___Argc, ___Argv ) );
}
#endif
